@@ -7,7 +7,7 @@ from df_to_azure.adf import create_blob_service_client
 import df_to_azure.adf as adf
 from df_to_azure.parse_settings import TableParameters
 from df_to_azure.db import SqlUpsert, auth_azure, test_uniqueness_columns
-from df_to_azure.functions import create_dir
+from df_to_azure.functions import create_dir, wait_until_pipeline_is_done
 
 
 def table_list(df_dict: dict, schema: str, method: str, id_field: str, cwd: str) -> list:
@@ -22,7 +22,9 @@ def table_list(df_dict: dict, schema: str, method: str, id_field: str, cwd: str)
     return tables
 
 
-def run_multiple(df_dict, schema, method="create", id_field=None, cwd=None):
+def run_multiple(
+    df_dict, schema, method="create", id_field=None, cwd=None, wait_till_finished=False
+):
 
     tables = table_list(df_dict, schema, method, id_field, cwd)
 
@@ -47,11 +49,13 @@ def run_multiple(df_dict, schema, method="create", id_field=None, cwd=None):
 
     # pipelines
     adf_client, run_response = adf.create_multiple_activity_pipeline(tables)
+    if wait_till_finished:
+        wait_until_pipeline_is_done(adf_client, run_response)
 
     return adf_client, run_response
 
 
-def run(df, tablename, schema, method="create", id_field=None, cwd=None):
+def run(df, tablename, schema, method="create", id_field=None, cwd=None, wait_till_finished=False):
     table = TableParameters(
         df=df, name=tablename, schema=schema, method=method, id_field=id_field, cwd=cwd
     )
@@ -74,6 +78,8 @@ def run(df, tablename, schema, method="create", id_field=None, cwd=None):
 
     # pipelines
     adf_client, run_response = adf.create_pipeline(table)
+    if wait_till_finished:
+        wait_until_pipeline_is_done(adf_client, run_response)
 
     return adf_client, run_response
 
@@ -101,7 +107,7 @@ def upload_dataset(table):
         push_to_azure(table)
 
     upload_to_blob(table)
-    logging.info(f"Finished.number of transactions:{len(table.df)}")
+    logging.info(f"Finished! exported {table.df.shape[0]} records.")
 
 
 def push_to_azure(table):
@@ -119,12 +125,8 @@ def push_to_azure(table):
         schema=table.schema,
         dtype=col_types,
     )
-    result = (
-        f"push successful ({table.name}):",
-        len(table.df),
-        f"records pushed to Microsoft Azure ({table.df.shape[1]} columns)",
-    )
-    logging.info(result)
+
+    logging.info(f"created {table.df.shape[1]} columns in {table.schema}.{table.name}.")
 
 
 def upload_to_blob(table):
@@ -138,13 +140,13 @@ def upload_to_blob(table):
     create_dir(tmp_path)
 
     table.df.to_csv(
-        full_path_to_file, index=False, sep="^", quotechar='"'
+        full_path_to_file, index=False, sep="^", quotechar='"', line_terminator=os.linesep
     )  # export file to staging
 
-    logging.info(f"start uploading blob {table.name}...")
+    logging.debug(f"start uploading blob {table.name}...")
     with open(full_path_to_file, "rb") as data:
         blob_client.upload_blob(data, overwrite=True)
-    logging.info(f"finished uploading blob {table.name}!")
+    logging.debug(f"finished uploading blob {table.name}!")
 
     os.remove(full_path_to_file)
 
